package com.persagy.labsl.services.impl

import com.persagy.labsl.models.entities.tpt.Graph
import com.persagy.labsl.models.entities.tpt.pub.GraphPub
import com.persagy.labsl.services.GraphLogicService
import com.persagy.labsl.services.GraphService
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import lombok.extern.slf4j.Slf4j
import org.springframework.stereotype.Service
import org.springframework.transaction.annotation.Transactional

/**
 * 图逻辑处理
 * @author : lijie
 * Update By 2022/5/27 18:25
 */
@Slf4j
@Service
open class GraphLogicServiceImpl : GraphLogicService {
    /**
     * 草稿箱-创建图
     * @author : lijie
     * Update By 2022/5/27 18:26
     */
    @Transactional
    override fun draftsCreate(request: SCreateRequest<Graph>): SCreateResponse<Graph> {
        return GraphService.draftsCreate(request);
    }
    /**
     * 草稿箱-保存图
     * @author : lijie
     * Update By 2022/5/27 18:35
     */
    @Transactional
    override fun save(graph: Graph): SCreateResponse<Graph> {
        return GraphService.save(graph);
    }
    /**
     * 发布草稿图
     * @author : lijie
     * Update By 2022/5/27 18:48
     */
    @Transactional
    override fun pubDrawings(graph: GraphPub): SCreateResponse<GraphPub> {
        return GraphService.pubDrawings(graph)
    }
    /**
     * 草稿移出/移至回收站
     * @author : lijie
     * Update By 2022/5/31 19:23
     */
    @Transactional
    override fun recycle(idList: ArrayList<Graph>): SBaseResponse {
        return GraphService.recycle(idList)
    }
    /**
     * 已发布图形移出/移至回收站
     * @author : lijie
     * Update By 2022/5/31 19:24
     */
    @Transactional
    override fun recyclePub(idList: ArrayList<Graph>): SBaseResponse {
        return GraphService.recyclePub(idList)
    }
    /**
     * 草稿的更新操作
     * @author : lijie
     * Update By 2022/5/31 19:31
     */
    @Transactional
    override fun draftsUpdate(request: SUpdateRequest<Graph>): SBaseResponse {
        return GraphService.draftsUpdate(request)
    }
    /**
     * 已发布操作的更新操作
     * @author : lijie
     * Update By 2022/5/31 19:31
     */
    @Transactional
    override fun pubUpdate(request: SUpdateRequest<GraphPub>): SBaseResponse {
       return GraphService.pubUpdate(request)
    }
    /**
     * 从回收站恢复图形
     * @author : lijie
     * Update By 2022/5/31 19:40
     */
    @Transactional
    override fun recovery(graph: Graph): SBaseResponse {
       return GraphService.recovery(graph)
    }
    /**
     * 根据id删除图形
     * @author : lijie
     * Update By 2022/5/31 19:43
     */
    @Transactional
    override fun deleteByKeysList(idList: ArrayList<Graph>): SBaseResponse {
       return GraphService.deleteByKeysList(idList)
    }
}